@@ -1,39 +1,3 @@
-package java.lang;
-
-import java.io.*;
-import java.security.CodeSource;
-import java.security.ProtectionDomain;
-
-import com.ibm.oti.vm.VM;
-
-import java.net.URL;
-import java.util.Enumeration;
-import java.util.HashMap;
-import java.util.Hashtable;
-import java.util.LinkedList;
-import java.util.Map;
-import java.util.NoSuchElementException;
-import java.util.Queue;
-import java.util.Vector;
-import java.util.Collections;
-import java.util.WeakHashMap;
-import java.util.stream.Stream;
-import java.lang.ref.ReferenceQueue;
-import java.lang.ref.WeakReference;
-import java.lang.reflect.*;
-import java.security.cert.Certificate;
-
-import java.lang.reflect.Modifier;
-import java.util.Spliterator;
-import java.util.Spliterators;
-import java.util.stream.StreamSupport;
-import jdk.internal.module.ServicesCatalog;
-import jdk.internal.misc.SharedSecrets;
-import java.util.concurrent.ConcurrentHashMap;
-import jdk.internal.reflect.CallerSensitive;
-import jdk.internal.loader.ClassLoaders;
-import jdk.internal.loader.BootLoader;
-
 /*******************************************************************************
  * Copyright (c) 1998, 2019 IBM Corp. and others
  *
@@ -55,6 +19,40 @@ import jdk.internal.loader.BootLoader;
  *
  * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
  *******************************************************************************/
+package java.lang;
+
+import java.io.*;
+import java.security.CodeSource;
+import java.security.ProtectionDomain;
+
+import com.ibm.oti.vm.VM;
+
+import java.net.URL;
+import java.util.Enumeration;
+import java.util.HashMap;
+import java.util.Hashtable;
+import java.util.LinkedList;
+import java.util.Map;
+import java.util.NoSuchElementException;
+import java.util.Queue;
+import java.util.Vector;
+import java.util.Collections;
+import java.util.WeakHashMap;
+import java.lang.ref.ReferenceQueue;
+import java.lang.ref.WeakReference;
+import java.lang.reflect.*;
+import java.security.cert.Certificate;
+
+import java.lang.reflect.Modifier;
+import java.util.Spliterator;
+import java.util.Spliterators;
+import java.util.stream.Stream;
+import java.util.stream.StreamSupport;
+import jdk.internal.module.ServicesCatalog;
+import java.util.concurrent.ConcurrentHashMap;
+import jdk.internal.reflect.CallerSensitive;
+import jdk.internal.loader.ClassLoaders;
+import jdk.internal.loader.BootLoader;
  
 /**
  * ClassLoaders are used to dynamically load, link and install
@@ -93,7 +91,7 @@ public abstract class ClassLoader {
   	private boolean defaultAssertionStatus;
   	private Map<String, Boolean> packageAssertionStatus;
   	private Map<String, Boolean> classAssertionStatus;
-  	private final Hashtable<String, NamedPackage> packages = new Hashtable();
+    private final Hashtable<String, NamedPackage> packages = new Hashtable<>();
   	private volatile ConcurrentHashMap<?, ?> classLoaderValueMap;
 	private static final class LazyInitLock { LazyInitLock() {} }
   	private final Object lazyInitLock = new LazyInitLock();
@@ -174,29 +172,17 @@ public abstract class ClassLoader {
 			// ignore
 		}
 
-		ClassLoader sysTemp = null;
-		// Proper initialization requires BootstrapLoader is the first loader instantiated
-		String systemLoaderString = System.internalGetProperties().getProperty("systemClassLoader"); //$NON-NLS-1$
-		if(null == systemLoaderString) {
-			// This static method call ensures jdk.internal.loader.ClassLoaders.BOOT_LOADER initialization first
-			jdk.internal.loader.ClassLoaders.platformClassLoader();
-			if (bootstrapClassLoader.servicesCatalog != null) {
-				throw new InternalError("bootstrapClassLoader.servicesCatalog is NOT null "); //$NON-NLS-1$
-			}
-			bootstrapClassLoader.servicesCatalog = BootLoader.getServicesCatalog();
-			if (bootstrapClassLoader.classLoaderValueMap != null) {
-				throw new InternalError("bootstrapClassLoader.classLoaderValueMap is NOT null "); //$NON-NLS-1$
-			}
-			bootstrapClassLoader.classLoaderValueMap = BootLoader.getClassLoaderValueMap();
-			applicationClassLoader = ClassLoaders.appClassLoader();
-		} else {
-			try {
-				sysTemp = (ClassLoader)Class.forName(systemLoaderString,true,null).newInstance();
-			} catch(Throwable x) {
-				x.printStackTrace();
-				System.exit(1);
-			}
+		// This static method call ensures jdk.internal.loader.ClassLoaders.BOOT_LOADER initialization first
+		jdk.internal.loader.ClassLoaders.platformClassLoader();
+		if (bootstrapClassLoader.servicesCatalog != null) {
+			throw new InternalError("bootstrapClassLoader.servicesCatalog is NOT null "); //$NON-NLS-1$
 		}
+		bootstrapClassLoader.servicesCatalog = BootLoader.getServicesCatalog();
+		if (bootstrapClassLoader.classLoaderValueMap != null) {
+			throw new InternalError("bootstrapClassLoader.classLoaderValueMap is NOT null "); //$NON-NLS-1$
+		}
+		bootstrapClassLoader.classLoaderValueMap = BootLoader.getClassLoaderValueMap();
+		applicationClassLoader = ClassLoaders.appClassLoader();
 
 		/* [PR 78889] The creation of this classLoader requires lazy initialization. The internal classLoader struct
 		 * is created in the initAnonClassLoader call. The "new InternalAnonymousClassLoader()" call must be 
@@ -501,13 +487,33 @@ final Class<?> defineClassInternal(
 	return answer;
 }
 
- /**
-  * Add a class's package name to this classloader's list of packages, if not already present.
+/**
+ * This class is a function that maps a package name to a newly created
+ * {@code NamedPackage} object for use below in updating the {@code packages} map.
+ */
+private static final class NamedPackageProvider implements java.util.function.Function<String, NamedPackage> {
+
+	private final Class<?> newClass;
+
+	NamedPackageProvider(Class<?> newClass) {
+		super();
+		this.newClass = newClass;
+	}
+
+	@Override
+	public NamedPackage apply(String pkgName) {
+		return new NamedPackage(pkgName, newClass.getModule());
+	}
+
+}
+
+/**
+ * Add a class's package name to this classloader's list of packages, if not already present.
  * @param newClass
  */
 void addPackageToList(Class<?> newClass) {
-	synchronized(packages) {
-		packages.computeIfAbsent(newClass.getPackageName(), pkgName->new NamedPackage(pkgName, newClass.getModule()));
+	synchronized (packages) {
+		packages.computeIfAbsent(newClass.getPackageName(), new NamedPackageProvider(newClass));
 	}
 }
 
@@ -881,6 +887,15 @@ static ClassLoader getClassLoader(Class<?> clz) {
 	}
 }
 
+/**
+ * Return the Platform classloader.
+ *
+ * If a security manager exists and it does not
+ * allow access a SecurityException will be thrown.
+ *
+ * @return the platformClassLoader
+ * @throws SecurityException if access to the platform classloader is denied
+ */
 @CallerSensitive
 public static ClassLoader getPlatformClassLoader() {
 	SecurityManager security = System.getSecurityManager();
@@ -1688,6 +1703,24 @@ static void loadLibraryWithPath(String libName, ClassLoader loader, String libra
 		}
 	}
 	byte[] message = ClassLoader.loadLibraryWithPath(com.ibm.oti.util.Util.getBytes(libName), loader, libraryPath == null ? null : com.ibm.oti.util.Util.getBytes(libraryPath));
+
+	/* As Mac OS X used to be using lib<name>.jnilib Java native library format,
+	 * VM will attempt loading native library using the legacy library extension
+	 * on Mac OS X to support older applications
+	 */
+	if (System.internalGetProperties().getProperty("os.name").equals("Mac OS X")) { //$NON-NLS-1$ //$NON-NLS-2$
+		if ((message != null) && (libraryPath != null)) {
+			String legacyPath = libraryPath.replaceAll("/$", "") + "/lib" + libName + ".jnilib"; //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
+
+			try {
+				byte[] jnilibLoadMessage = ClassLoader.loadLibraryWithPath(com.ibm.oti.util.Util.getBytes(legacyPath), loader, null);
+				if (jnilibLoadMessage == null) {
+					message = null;
+				}
+			} catch (Exception e) { /* Ignore Exception */ }
+		}
+	}
+
 	if (message != null) {
 		String error;
 		try {
@@ -2088,6 +2121,8 @@ ServicesCatalog getServicesCatalog() {
  * 					the module name
  * @param		resName String
  *					the name of the resource to find.
+ *
+ * @throws IOException when an error occurs
  */
 protected URL findResource(String moduleName, String resName) throws IOException {
 	URL result = null;
@@ -2163,4 +2198,3 @@ public final boolean isRegisteredAsParallelCapable() {
 }
 
 }
-
