@@ -234,8 +234,8 @@ module java.base {
     exports jdk.internal.vm.annotation to
         jdk.internal.vm.ci,
         jdk.unsupported;
-    exports openj9.tools.attach.diagnostics.base to jdk.jcmd;
-    exports openj9.tools.attach.diagnostics.spi to
+    exports openj9.management.internal to java.management;
+    exports openj9.tools.attach.diagnostics.base to
         jdk.attach,
         jdk.jcmd;
     exports sun.net to
@@ -357,7 +357,6 @@ module java.base {
     uses java.util.spi.ToolProvider;
     uses javax.security.auth.spi.LoginModule;
     uses jdk.internal.logger.DefaultLoggerFinder;
-    uses openj9.tools.attach.diagnostics.spi.TargetDiagnosticsProvider;
     uses sun.text.spi.JavaTimeDateTimePatternProvider;
     uses sun.util.locale.provider.LocaleDataMetaInfo;
     uses sun.util.resources.LocaleData.CommonResourceBundleProvider;
